@@ -119,11 +119,18 @@ package version::vpp;
 
 use 5.006002;
 use strict;
+use warnings::register;
 
 use Config;
-use vars qw($VERSION $CLASS @ISA $LAX $STRICT);
-$VERSION = 0.9911;
+use vars qw($VERSION $CLASS @ISA $LAX $STRICT $WARN_CATEGORY);
+$VERSION = 0.9913;
 $CLASS = 'version::vpp';
+if ($] > 5.015) {
+    warnings::register_categories(qw/version/);
+    $WARN_CATEGORY = 'version';
+} else {
+    $WARN_CATEGORY = 'numeric';
+}
 
 require version::regex;
 *version::vpp::is_strict = \&version::regex::is_strict;
@@ -148,16 +155,6 @@ use overload (
     'abs'      => \&vnoop,
 );
 
-eval "use warnings";
-if ($@) {
-    eval '
-	package
-	warnings;
-	sub enabled {return $^W;}
-	1;
-    ';
-}
-
 sub import {
     no strict 'refs';
     my ($class) = shift;
@@ -196,7 +193,7 @@ sub import {
     }
 
     if (exists($args{'UNIVERSAL::VERSION'})) {
-	local $^W;
+	no warnings qw/redefine/;
 	*UNIVERSAL::VERSION
 		= \&{$CLASS.'::_VERSION'};
     }
@@ -503,7 +500,7 @@ sub scan_version {
 	$$rv->{width} = $width;
     }
 
-    while (isDIGIT($pos)) {
+    while (isDIGIT($pos) || $pos eq '_') {
 	$pos++;
     }
     if (!isALPHA($pos)) {
@@ -524,6 +521,7 @@ sub scan_version {
  		if ( !$qv && $s > $start && $saw_decimal == 1 ) {
 		    $mult *= 100;
  		    while ( $s < $end ) {
+			next if $s eq '_';
 			$orev = $rev;
  			$rev += $s * $mult;
  			$mult /= 10;
@@ -543,6 +541,7 @@ sub scan_version {
   		}
  		else {
  		    while (--$end >= $s) {
+			next if $end eq '_';
 			$orev = $rev;
  			$rev += $end * $mult;
  			$mult *= 10;
@@ -580,7 +579,7 @@ sub scan_version {
 		last;
 	    }
 	    if ( $qv ) {
-		while ( isDIGIT($pos) ) {
+		while ( isDIGIT($pos) || $pos eq '_') {
 		    $pos++;
 		}
 	    }
@@ -700,7 +699,7 @@ sub new {
     my $s = scan_version($value, \$self, $qv);
 
     if ($s) { # must be something left over
-	warn("Version string '%s' contains invalid data; "
+	warn(sprintf "Version string '%s' contains invalid data; "
 		   ."ignoring: '%s'", $value, $s);
     }
 
@@ -715,34 +714,21 @@ sub numify {
 	require Carp;
 	Carp::croak("Invalid version object");
     }
-    my $width = $self->{width} || 3;
     my $alpha = $self->{alpha} || "";
     my $len = $#{$self->{version}};
     my $digit = $self->{version}[0];
     my $string = sprintf("%d.", $digit );
 
-    for ( my $i = 1 ; $i < $len ; $i++ ) {
-	$digit = $self->{version}[$i];
-	if ( $width < 3 ) {
-	    my $denom = 10**(3-$width);
-	    my $quot = int($digit/$denom);
-	    my $rem = $digit - ($quot * $denom);
-	    $string .= sprintf("%0".$width."d_%d", $quot, $rem);
-	}
-	else {
-	    $string .= sprintf("%03d", $digit);
-	}
+    if ($alpha and warnings::enabled()) {
+	warnings::warn($WARN_CATEGORY, 'alpha->numify() is lossy');
     }
 
-    if ( $len > 0 ) {
-	$digit = $self->{version}[$len];
-	if ( $alpha && $width == 3 ) {
-	    $string .= "_";
-	}
-	$string .= sprintf("%0".$width."d", $digit);
+    for ( my $i = 1 ; $i <= $len ; $i++ ) {
+	$digit = $self->{version}[$i];
+	$string .= sprintf("%03d", $digit);
     }
-    else # $len = 0
-    {
+
+    if ( $len == 0 ) {
 	$string .= sprintf("000");
     }
 
@@ -755,32 +741,16 @@ sub normal {
 	require Carp;
 	Carp::croak("Invalid version object");
     }
-    my $alpha = $self->{alpha} || "";
-    my $qv = $self->{qv} || "";
-    if ($alpha and not $qv) {
-	# can't do this
-	require Carp;
-	Carp::croak("Invalid version method call");
-    }
+
     my $len = $#{$self->{version}};
     my $digit = $self->{version}[0];
     my $string = sprintf("v%d", $digit );
 
-    for ( my $i = 1 ; $i < $len ; $i++ ) {
+    for ( my $i = 1 ; $i <= $len ; $i++ ) {
 	$digit = $self->{version}[$i];
 	$string .= sprintf(".%d", $digit);
     }
 
-    if ( $len > 0 ) {
-	$digit = $self->{version}[$len];
-	if ( $alpha ) {
-	    $string .= sprintf("_%0d", $digit);
-	}
-	else {
-	    $string .= sprintf(".%0d", $digit);
-	}
-    }
-
     if ( $len <= 2 ) {
 	for ( $len = 2 - $len; $len != 0; $len-- ) {
 	    $string .= sprintf(".%0d", 0);
@@ -804,7 +774,6 @@ sub stringify {
 }
 
 sub vcmp {
-    require UNIVERSAL;
     my ($left,$right,$swap) = @_;
     my $class = ref($left);
     unless ( UNIVERSAL::isa($right, $class) ) {
@@ -834,20 +803,6 @@ sub vcmp {
 	$i++;
     }
 
-    # tiebreaker for alpha with identical terms
-    if ( $retval == 0
-	&& $l == $r
-	&& $left->{version}[$m] == $right->{version}[$m]
-	&& ( $lalpha || $ralpha ) ) {
-
-	if ( $lalpha && !$ralpha ) {
-	    $retval = -1;
-	}
-	elsif ( $ralpha && !$lalpha) {
-	    $retval = +1;
-	}
-    }
-
     # possible match except for trailing 0's
     if ( $retval == 0 && $l != $r ) {
 	if ( $l < $r ) {
